@@ -1,8 +1,7 @@
 from __future__ import print_function, division, absolute_import
 
-from .center import Center
-from .client import scatter, gather, delete, clear, rpc
-from .core import connect, read, write
+from .config import config
+from .core import connect, read, write, rpc
 from .deploy import LocalCluster
 from .diagnostics import progress
 from .executor import (Executor, CompatibleExecutor, wait, as_completed,
@@ -11,6 +10,7 @@ from .nanny import Nanny
 from .scheduler import Scheduler
 from .utils import sync
 from .worker import Worker
+from .worker_executor import local_executor
 
 try:
     from .collections import futures_to_collection
@@ -18,4 +18,4 @@ except:
     pass
 
 
-__version__ = '1.12.1'
+__version__ = '1.12.2'
