@@ -18,14 +18,13 @@ except ImportError:
     import pickle
 import cloudpickle
 from tornado import gen
-from tornado.gen import Return
 from tornado.locks import Event
 from tornado.tcpserver import TCPServer
 from tornado.tcpclient import TCPClient
 from tornado.ioloop import IOLoop
 from tornado.iostream import IOStream, StreamClosedError
 
-from .compatibility import PY3, unicode
+from .compatibility import PY3, unicode, WINDOWS
 from .utils import get_traceback, truncate_exception, ignoring
 from . import protocol
 
@@ -99,7 +98,7 @@ def handle_signal(sig, frame):
 class Server(TCPServer):
     """ Distributed TCP Server
 
-    Superclass for both Worker and Center objects.
+    Superclass for both Worker and Scheduler objects.
     Inherits from ``tornado.tcpserver.TCPServer``, adding a protocol for RPC.
 
     **Handlers**
@@ -205,8 +204,8 @@ class Server(TCPServer):
                 try:
                     handler = self.handlers[op]
                 except KeyError:
-                    result = 'No handler found: ' + op.encode()
-                    logger.warn(result)
+                    result = "No handler found: %s" % op
+                    logger.warn(result, exc_info=True)
                 else:
                     logger.debug("Calling into handler %s", handler.__name__)
                     try:
@@ -240,7 +239,7 @@ def read(stream):
     """ Read a message from a stream """
     if isinstance(stream, BatchedStream):
         msg = yield stream.recv()
-        raise Return(msg)
+        raise gen.Return(msg)
     else:
         n_frames = yield stream.read_bytes(8)
         n_frames = struct.unpack('Q', n_frames)[0]
@@ -257,7 +256,7 @@ def read(stream):
             frames.append(frame)
 
         msg = protocol.loads(frames)
-        raise Return(msg)
+        raise gen.Return(msg)
 
 
 @gen.coroutine
@@ -273,14 +272,21 @@ def write(stream, msg):
             logger.exception(e)
             raise
 
+        futures = []
+
         lengths = ([struct.pack('Q', len(frames))] +
                    [struct.pack('Q', len(frame)) for frame in frames])
-        stream.write(b''.join(lengths))
+        futures.append(stream.write(b''.join(lengths)))
 
         for frame in frames[:-1]:
-            stream.write(frame)
+            futures.append(stream.write(frame))
 
-        yield stream.write(frames[-1])
+        futures.append(stream.write(frames[-1]))
+
+        if WINDOWS:
+            yield futures[-1]
+        else:
+            yield futures
 
 
 def pingpong(stream):
@@ -296,7 +302,7 @@ def connect(ip, port, timeout=3):
         try:
             stream = yield gen.with_timeout(timedelta(seconds=timeout), future)
             stream.set_nodelay(True)
-            raise Return(stream)
+            raise gen.Return(stream)
         except StreamClosedError:
             if time() - start < timeout:
                 yield gen.sleep(0.01)
@@ -344,7 +350,8 @@ def send_recv(stream=None, arg=None, ip=None, port=None, addr=None, reply=True,
         response = None
     if kwargs.get('close'):
         stream.close()
-    raise Return(response)
+    raise gen.Return(response)
+
 
 def ip_port_from_args(arg=None, addr=None, ip=None, port=None):
     if arg:
@@ -363,6 +370,7 @@ def ip_port_from_args(arg=None, addr=None, ip=None, port=None):
 
     return ip, port
 
+
 class rpc(object):
     """ Conveniently interact with a remote server
 
@@ -397,6 +405,10 @@ class rpc(object):
         assert self.ip
         assert self.port
 
+    @property
+    def address(self):
+        return '%s:%d' % (self.ip, self.port)
+
     @gen.coroutine
     def live_stream(self):
         """ Get an open stream
@@ -430,7 +442,7 @@ class rpc(object):
         for s in to_clear:
             del self.streams[s]
         self.streams[stream] = False     # mark as taken
-        raise Return(stream)
+        raise gen.Return(stream)
 
     def close_streams(self):
         for stream in self.streams:
@@ -446,7 +458,7 @@ class rpc(object):
             stream = yield self.live_stream()
             result = yield send_recv(stream=stream, op=key, **kwargs)
             self.streams[stream] = True  # mark as open
-            raise Return(result)
+            raise gen.Return(result)
         return send_recv_from_rpc
 
     def __del__(self):
