@@ -2,12 +2,14 @@ from __future__ import print_function, division, absolute_import
 
 from collections import defaultdict, Iterator, Iterable
 from concurrent.futures._base import DoneAndNotDoneFutures, CancelledError
+from contextlib import contextmanager
 import copy
 from datetime import timedelta
 from functools import partial
 import logging
 import os
 import sys
+import pickle
 from time import sleep
 import uuid
 from threading import Thread
@@ -192,6 +194,15 @@ class Future(WrappedKey):
             self._cleared = True
             self.executor._dec_ref(tokey(self.key))
 
+    def __getstate__(self):
+        return self.key
+
+    def __setstate__(self, key):
+        e = default_executor()
+        Future.__init__(self, key, e)
+        e._send_to_scheduler({'op': 'update-graph', 'tasks': {},
+                              'keys': [tokey(self.key)], 'client': e.id})
+
     def __del__(self):
         self.release()
 
@@ -975,6 +986,105 @@ class Executor(object):
         """
         return sync(self.loop, self._cancel, futures)
 
+    @gen.coroutine
+    def _publish_dataset(self, **kwargs):
+        coroutines = []
+        for name, data in kwargs.items():
+            keys = [tokey(f.key) for f in futures_of(data)]
+            coroutines.append(self.scheduler.publish_dataset(keys=keys,
+                name=tokey(name), data=dumps(data), client=self.id))
+
+        outs = yield coroutines
+
+    def publish_dataset(self, **kwargs):
+        """
+        Publish named datasets to scheduler
+
+        This stores a named reference to a dask collection or list of futures
+        on the scheduler.  These references are available to other executors
+        which can download the collection or futures with ``get_dataset``.
+
+        Datasets are not immediately computed.  You may wish to call
+        ``Executor.persist`` prior to publishing a dataset.
+
+        Parameters
+        ----------
+        kwargs: dict
+            named collections to publish on the scheduler
+
+        Examples
+        --------
+        Publishing client:
+        >>> df = dd.read_csv('s3://...')  # doctest: +SKIP
+        >>> df = e.persist(df) # doctest: +SKIP
+        >>> e.publish_dataset(my_dataset=df)  # doctest: +SKIP
+
+        Receiving client:
+        >>> e.list_datasets()  # doctest: +SKIP
+        ['my_dataset']
+        >>> df2 = e.get_dataset('my_dataset')  # doctest: +SKIP
+
+        Returns
+        -------
+        None
+
+        See Also
+        --------
+        Executor.list_datasets
+        Executor.get_dataset
+        Executor.unpublish_dataset
+        Executor.persist
+        """
+        return sync(self.loop, self._publish_dataset, **kwargs)
+
+    def unpublish_dataset(self, name):
+        """
+        Remove named datasets from scheduler
+
+        Examples
+        --------
+        >>> e.list_datasets()  # doctest: +SKIP
+        ['my_dataset']
+        >>> e.unpublish_datasets('my_dataset')  # doctest: +SKIP
+        >>> e.list_datasets()  # doctest: +SKIP
+        []
+
+        See Also
+        --------
+        Executor.publish_dataset
+        """
+        return sync(self.loop, self.scheduler.unpublish_dataset, name=name)
+
+    def list_datasets(self):
+        """
+        List named datasets available on the scheduler
+
+        See Also
+        --------
+        Executor.publish_dataset
+        Executor.get_dataset
+        """
+        return sync(self.loop, self.scheduler.list_datasets)
+
+    @gen.coroutine
+    def _get_dataset(self, name):
+        out = yield self.scheduler.get_dataset(name=name, client=self.id)
+
+        with temp_default_executor(self):
+            data = loads(out['data'])
+        raise Return(data)
+
+    def get_dataset(self, name):
+        """
+        Get named dataset from the scheduler
+
+        See Also
+        --------
+        Executor.publish_dataset
+        Executor.list_datasets
+        """
+        return sync(self.loop, self._get_dataset, tokey(name))
+
     @gen.coroutine
     def _run(self, function, *args, **kwargs):
         workers = kwargs.pop('workers', None)
@@ -1327,7 +1437,7 @@ class Executor(object):
     @gen.coroutine
     def _rebalance(self, futures=None, workers=None):
         yield _wait(futures)
-        keys = list({f.key for f in self.futures_of(futures)})
+        keys = list({tokey(f.key) for f in self.futures_of(futures)})
         result = yield self.scheduler.rebalance(keys=keys, workers=workers)
         assert result['status'] == 'OK'
 
@@ -1355,7 +1465,7 @@ class Executor(object):
     def _replicate(self, futures, n=None, workers=None, branching_factor=2):
         futures = self.futures_of(futures)
         yield _wait(futures)
-        keys = {f.key for f in futures}
+        keys = {tokey(f.key) for f in futures}
         yield self.scheduler.replicate(keys=list(keys), n=n, workers=workers,
                 branching_factor=branching_factor)
 
@@ -1904,3 +2014,20 @@ def futures_of(o, executor=None):
             raise CancelledError(bad)
 
     return list(futures)
+
+
+@contextmanager
+def temp_default_executor(e):
+    """ Set the default executor for the duration of the context
+
+    Parameters
+    ----------
+    e : Executor
+        This is what default_executor() will return within the with-block.
+    """
+    old_exec = default_executor()
+    _global_executor[0] = e
+    try:
+        yield
+    finally:
+        _global_executor[0] = old_exec
