@@ -2,20 +2,16 @@
 from __future__ import print_function, division, absolute_import
 
 import logging
-import json
 from math import log
 import os
-import io
 from warnings import warn
 
-from dask.delayed import delayed
-from dask.base import tokenize
 import dask.bytes.core
+from dask.delayed import delayed
 from toolz import merge
+from hdfs3 import HDFileSystem
 
-from .compatibility import unicode
 from .executor import default_executor, ensure_default_get
-from .utils import ensure_bytes
 
 
 logger = logging.getLogger(__name__)
@@ -37,7 +33,6 @@ def get_block_locations(hdfs, filename):
 
 def read_block_from_hdfs(filename, offset, length, host=None, port=None,
         delimiter=None):
-    from hdfs3 import HDFileSystem
     from locket import lock_file
     with lock_file('.lock'):
         hdfs = HDFileSystem(host=host, port=port)
@@ -45,6 +40,22 @@ def read_block_from_hdfs(filename, offset, length, host=None, port=None,
     return bytes
 
 
+def open_file_write(paths, hdfs=None, **kwargs):
+    """ Open list of files using delayed """
+    if hdfs is None:
+        hdfs = HDFileSystem(kwargs.get('host'), kwargs.get('port'))
+    out = [delayed(hdfs.open)(path, 'wb') for path in paths]
+    return out
+
+
+def open_file_write_direct(path, hdfs=None, **kwargs):
+    if hdfs is None:
+        hdfs = HDFileSystem(kwargs.get('host'), kwargs.get('port'))
+    return hdfs.open(path, 'wb')
+
+dask.bytes.core._open_files_write['hdfs'] = open_file_write_direct
+
+
 def read_bytes(path, executor=None, hdfs=None, lazy=True, delimiter=None,
                not_zero=False, sample=True, blocksize=None, compression=None, **hdfs_auth):
     """ Convert location in HDFS to a list of distributed futures
@@ -71,7 +82,6 @@ def read_bytes(path, executor=None, hdfs=None, lazy=True, delimiter=None,
     """
     if compression:
         raise NotImplementedError("hdfs compression")
-    from hdfs3 import HDFileSystem
     hdfs = hdfs or HDFileSystem(**hdfs_auth)
     executor = default_executor(executor)
     blocks = get_block_locations(hdfs, path)
@@ -112,7 +122,6 @@ dask.bytes.core._read_bytes['hdfs'] = read_bytes
 
 
 def hdfs_open_file(path, auth):
-    from hdfs3 import HDFileSystem
     hdfs = HDFileSystem(**auth)
     return hdfs.open(path, mode='rb')
 
@@ -121,7 +130,6 @@ def open_files(path, hdfs=None, lazy=None, **auth):
     if lazy is not None:
         raise DeprecationWarning("Lazy keyword has been deprecated. "
                                  "Now always lazy")
-    from hdfs3 import HDFileSystem
     hdfs = hdfs or HDFileSystem(**auth)
     filenames = sorted(hdfs.glob(path))
     myopen = delayed(hdfs_open_file)
@@ -131,59 +139,6 @@ def open_files(path, hdfs=None, lazy=None, **auth):
 dask.bytes.core._open_files['hdfs'] = open_files
 
 
-def write_block_to_hdfs(fn, data, hdfs=None):
-    """ Write bytes to HDFS """
-    if not isinstance(data, bytes):
-        raise TypeError("Data to write to HDFS must be of type bytes, got %s" %
-                        type(data).__name__)
-    with hdfs.open(fn, 'wb') as f:
-        f.write(data)
-    return len(data)
-
-
-def write_bytes(path, futures, executor=None, hdfs=None, **hdfs_auth):
-    """ Write bytestring futures to HDFS
-
-    Parameters
-    ----------
-    path: string
-        Path on HDFS to write data.  Either globstring like ``/data/file.*.dat``
-        or a directory name like ``/data`` (directory will be created)
-    futures: list
-        List of futures.  Each future should refer to a block of bytes.
-    executor: Executor
-    hdfs: HDFileSystem
-
-    Returns
-    -------
-    Futures that wait until writing is complete.  Returns the number of bytes
-    written.
-
-    Examples
-    --------
-
-    >>> write_bytes('/data/file.*.dat', futures, hdfs=hdfs)  # doctest: +SKIP
-    >>> write_bytes('/data/', futures, hdfs=hdfs)  # doctest: +SKIP
-    """
-    from hdfs3 import HDFileSystem
-    hdfs = hdfs or HDFileSystem(**hdfs_auth)
-    executor = default_executor(executor)
-
-    n = len(futures)
-    n_digits = int(log(n) / log(10))
-    template = '%0' + str(n_digits) + 'd'
-
-    if '*' in path:
-        dirname = os.path.split(path)[0]
-        hdfs.mkdir(dirname)
-        filenames = [path.replace('*', template % i) for i in range(n)]
-    else:
-        hdfs.mkdir(path)
-        filenames = [os.path.join(path, template % i) for i in range(n)]
-
-    return executor.map(write_block_to_hdfs, filenames, futures, hdfs=hdfs)
-
-
 def read_text(path, encoding='utf-8', errors='strict', lineterminator='\n',
                executor=None, hdfs=None, lazy=True, collection=True):
     """ Read text lines from HDFS
