@@ -7,6 +7,7 @@ from concurrent.futures import CancelledError
 from datetime import timedelta
 import itertools
 from multiprocessing import Process
+import pickle
 from random import random, choice
 import sys
 from threading import Thread
@@ -28,13 +29,13 @@ from distributed import Worker, Nanny
 from distributed.client import WrappedKey
 from distributed.executor import (Executor, Future, CompatibleExecutor, _wait,
         wait, _as_completed, as_completed, tokenize, _global_executor,
-        default_executor, _first_completed, ensure_default_get, futures_of)
+        default_executor, _first_completed, ensure_default_get, futures_of,
+        temp_default_executor)
 from distributed.scheduler import Scheduler, KilledWorker
 from distributed.sizeof import sizeof
 from distributed.utils import sync, tmp_text, ignoring, tokey, All
 from distributed.utils_test import (cluster, slow, slowinc, slowadd, randominc,
-        _test_scheduler, loop, inc, dec, div, throws, gen_cluster, gen_test,
-        double, deep)
+        loop, inc, dec, div, throws, gen_cluster, gen_test, double, deep)
 
 
 @gen_cluster(executor=True, timeout=None)
@@ -2462,6 +2463,15 @@ def test_replicate(e, s, *workers):
     assert sum(b.key in w.data for w in workers) == 5
 
 
+@gen_cluster(executor=True)
+def test_replicate_tuple_keys(e, s, a, b):
+    x = delayed(inc)(1, dask_key_name=('x', 1))
+    f = e.persist(x)
+    yield e._replicate(f, n=5)
+    assert a.data and b.data
+
+    yield e._rebalance(f)
+
 @gen_cluster(executor=True, ncores=[('127.0.0.1', 1)] * 10)
 def test_replicate_workers(e, s, *workers):
 
@@ -3202,6 +3212,117 @@ def test_threaded_get_within_distributed(loop):
                 future = e.submit(f)
                 assert future.result() == 1
 
+
+@gen_cluster(executor=False)
+def test_publish_simple(s, a, b):
+    e = Executor((s.ip, s.port), start=False)
+    yield e._start()
+    f = Executor((s.ip, s.port), start=False)
+    yield f._start()
+
+    data = yield e._scatter(range(3))
+    out = yield e._publish_dataset(data=data)
+    assert 'data' in s.datasets
+
+    with pytest.raises(KeyError) as exc_info:
+        out = yield e._publish_dataset(data=data)
+
+    assert "exists" in str(exc_info.value)
+    assert "data" in str(exc_info.value)
+
+    result = yield e.scheduler.list_datasets()
+    assert result == ['data']
+
+    result = yield f.scheduler.list_datasets()
+    assert result == ['data']
+
+
+@gen_cluster(executor=False)
+def test_publish_roundtrip(s, a, b):
+    e = Executor((s.ip, s.port), start=False)
+    yield e._start()
+    f = Executor((s.ip, s.port), start=False)
+    yield f._start()
+
+    data = yield e._scatter([0, 1, 2])
+    yield e._publish_dataset(data=data)
+
+    assert 'published-data' in s.who_wants[data[0].key]
+    result = yield f._get_dataset(name='data')
+
+    assert len(result) == len(data)
+    out = yield f._gather(result)
+    assert out == [0, 1, 2]
+
+    with pytest.raises(KeyError) as exc_info:
+        result = yield f._get_dataset(name='nonexistent')
+
+    assert "not found" in str(exc_info.value)
+    assert "nonexistent" in str(exc_info.value)
+
+
+@gen_cluster(executor=True)
+def test_unpublish(e, s, a, b):
+    data = yield e._scatter([0, 1, 2])
+    yield e._publish_dataset(data=data)
+
+    key = data[0].key
+    del data
+
+    yield e.scheduler.unpublish_dataset(name='data')
+
+    assert 'data' not in s.datasets
+
+    start = time()
+    while key in s.who_wants:
+        yield gen.sleep(0.01)
+        assert time() < start + 5
+
+    with pytest.raises(KeyError) as exc_info:
+        result = yield e._get_dataset(name='data')
+
+    assert "not found" in str(exc_info.value)
+    assert "data" in str(exc_info.value)
+
+
+@gen_cluster(executor=True)
+def test_publish_multiple_datasets(e, s, a, b):
+    x = delayed(inc)(1)
+    y = delayed(inc)(2)
+
+    yield e._publish_dataset(x=x, y=y)
+    datasets = yield e.scheduler.list_datasets()
+    assert set(datasets) == {'x', 'y'}
+
+
+@gen_cluster(executor=False)
+def test_publish_bag(s, a, b):
+    db = pytest.importorskip('dask.bag')
+    e = Executor((s.ip, s.port), start=False)
+    yield e._start()
+    f = Executor((s.ip, s.port), start=False)
+    yield f._start()
+
+    bag = db.from_sequence([0, 1, 2])
+    bagp = e.persist(bag)
+
+    assert len(futures_of(bagp)) == 3
+    keys = {f.key for f in futures_of(bagp)}
+    assert keys == set(bag.dask)
+
+    yield e._publish_dataset(data=bagp)
+
+    # check that serialization didn't affect original bag's dask
+    assert len(futures_of(bagp)) == 3
+
+    result = yield f._get_dataset('data')
+    assert set(result.dask.keys()) == set(bagp.dask.keys())
+    assert {f.key for f in result.dask.values()} == {f.key for f in bagp.dask.values()}
+
+    out = yield f.compute(result)._result()
+    assert out == [0, 1, 2]
+
+
 @gen_cluster(executor=True)
 def test_lose_scattered_data(e, s, a, b):
     [x] = yield e._scatter([1], workers=a.address)
@@ -3317,3 +3438,36 @@ def test_scatter_compute_store_lose_processing(e, s, a, b):
     assert y.status == 'cancelled'
     assert z.status == 'cancelled'
 
+
+@gen_cluster(executor=False)
+def test_serialize_future(s, a, b):
+    e = Executor((s.ip, s.port), start=False)
+    yield e._start()
+    f = Executor((s.ip, s.port), start=False)
+    yield f._start()
+
+    future = e.submit(lambda: 1)
+    result = yield future._result()
+
+    with temp_default_executor(f):
+        future2 = pickle.loads(pickle.dumps(future))
+        assert future2.executor is f
+        assert tokey(future2.key) in f.futures
+        result2 = yield future2._result()
+        assert result == result2
+
+
+@gen_cluster(executor=False)
+def test_temp_executor(s, a, b):
+    e = Executor((s.ip, s.port), start=False)
+    yield e._start()
+    f = Executor((s.ip, s.port), start=False)
+    yield f._start()
+
+    with temp_default_executor(e):
+        assert default_executor() is e
+        assert default_executor(f) is f
+
+    with temp_default_executor(f):
+        assert default_executor() is f
+        assert default_executor(e) is e
