@@ -40,6 +40,9 @@ bob = 'bob:1234'
 def test_administration(s, a, b):
     assert isinstance(s.address, str)
     assert s.address_tuple[0] in s.address
+    assert s.address in str(s)
+    assert str(sum(s.ncores.values())) in repr(s)
+    assert str(len(s.ncores)) in repr(s)
 
 
 @gen_cluster()
@@ -626,15 +629,6 @@ def test_delete_data(e, s, a, b):
         assert time() < start + 5
 
 
-@gen_cluster()
-def test_rpc(s, a, b):
-    aa = s.rpc(ip=a.ip, port=a.port)
-    aa2 = s.rpc(ip=a.ip, port=a.port)
-    bb = s.rpc(ip=b.ip, port=b.port)
-    assert aa is aa2
-    assert aa is not bb
-
-
 @gen_cluster(executor=True)
 def test_delete_callback(e, s, a, b):
     d = yield e._scatter({'x': 1}, workers=a.address)
@@ -808,13 +802,16 @@ def test_ready_add_worker(s, a, b):
 
 
 @gen_cluster()
-def test_ready_add_worker(s, a, b):
+def test_broadcast(s, a, b):
     result = yield s.broadcast(msg={'op': 'ping'})
     assert result == {a.address: b'pong', b.address: b'pong'}
 
     result = yield s.broadcast(msg={'op': 'ping'}, workers=[a.address])
     assert result == {a.address: b'pong'}
 
+    result = yield s.broadcast(msg={'op': 'ping'}, hosts=[a.ip])
+    assert result == {a.address: b'pong', b.address: b'pong'}
+
 
 @gen_test()
 def test_worker_name():
@@ -902,7 +899,7 @@ def test_host_health(s, a, b, c):
         assert w.ip in s.host_info
         assert 0 <= s.host_info[w.ip]['cpu'] <= 100
         assert 0 < s.host_info[w.ip]['memory']
-        assert 0 < s.host_info[w.ip]['memory-percent'] < 100
+        assert 0 < s.host_info[w.ip]['memory_percent'] < 100
 
         assert isinstance(s.host_info[w.ip]['last-seen'], (int, float))
         assert -1 < s.worker_info[w.address]['time-delay'] < 1
@@ -960,3 +957,17 @@ def test_transition_story(e, s, a, b):
     assert all(x.key == line[0] or x.key in line[-1] for line in story)
 
     assert len(s.transition_story(x.key, y.key)) > len(story)
+
+
+@gen_test()
+def test_launch_without_blocked_services():
+    from distributed.http import HTTPScheduler
+    s = Scheduler(services={('http', 3849): HTTPScheduler})
+    s.start(0)
+
+    s2 = Scheduler(services={('http', 3849): HTTPScheduler})
+    s2.start(0)
+
+    assert not s2.services
+
+    yield [s.close(), s2.close()]
